Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/dynapydantic/__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | 4 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/subclass_tracking_model.py | 37 | 0 | 0 | 10 | 0 | 100%
src/dynapydantic/tracking_group.py | 61 | 0 | 0 | 22 | 0 | 100%
Total | 106 | 0 | 0 | 32 | 0 | 100%

No items found using the specified filter.